Examples of simple applications for Flask-AppBuilder
----------------------------------------------------

:basefilter: Simple contacts application where contacts are filtered by the user who has created them. The user only "sees" his/her contacts

:employees: Shows how to setup many to many relationships and a simple custom security class (creates an action to delete multiple users)

:extendedsecurity: Simple contacts application where contacts are filtered by the user's company who has created them. The user only "sees" his/her companies contacts. It also extends the User Model adding a company relationship and employee number.

:factoryapp: Simple example to show how to use a factory setup

:masterdetail: Shows how to use a master detail view

:mongoengine: Simple Contacts application example using MongoEngine support for MongoDB.

:mongoimages: Simple Contacts application with files and images example. Using MongoEngine support for MongoDB.

:oauth: OAuth authentication with twitter or google, sending tweets on behalf of their user.

:productsale: Just another simple app.

:quickactions: Show how to setup actions for list views.

:quickcharts: Simple application using chart views.

:quickfiles: Show how to use files with your models, upload, download and assoc with records.

:quickhowto: Simple contacts application from the docs.

:quickimages: The contacts application with images (upload and render on list).

:quickminimal: How to setup a minimal application, one file only.

:quicktemplates: Shows how to override the base template and create a different menu.

:simpleform: Shows how to render a simple form not backed by database models.

:simpleview1: The simple view, base applications, shows how to expose and render.

:simpleview2: Same as simpleview1, but the views use the base template.

:user_registration: Shows how to setup, db authentication and self user registration.

:related_fields: Simple example with two select2 related fields.

:widgets: A show case for the various builtin widgets.

